#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generically
version:              0.1.1
visibility:           public
id:                   generically-0.1.1-I9byc5Nil798plofO827gA
key:                  generically-0.1.1-I9byc5Nil798plofO827gA
license:              BSD-3-Clause
copyright:            2022 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus
synopsis:             Generically newtype to use with DerivingVia
description:
    This is a compatibility package as @Generically@ and @Generically1@ newtypes
    are available since @base-4.17@ in '\''GHC.Generics'\''.

category:             Generics
abi:                  a966d1c318b17a79d00e674bf60b9925
exposed:              True
exposed-modules:      GHC.Generics.Generically
import-dirs:          /usr/lib/ghc-9.6.6/site-local/generically-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/generically-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/generically-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generically
hs-libraries:         HSgenerically-0.1.1-I9byc5Nil798plofO827gA
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-generically/html/generically.haddock
haddock-html:         /usr/share/doc/haskell-generically/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

